@@ -12,8 +12,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import logging
-
 from django.utils.translation import ugettext_lazy as _
 from horizon import exceptions
 from horizon import tabs
@@ -22,8 +20,6 @@ from tacker_horizon.openstack_dashboard import api
 from tacker_horizon.openstack_dashboard.dashboards.nfv import utils
 from tacker_horizon.openstack_dashboard.dashboards.nfv.vnfmanager import tables
 
-LOG = logging.getLogger(__name__)
-
 
 class VNFManagerTab(tabs.TableTab):
     name = _("VNFManager Tab")
